@@ -144,7 +144,7 @@ ImageWidget::~ImageWidget()
 
 void ImageWidget::loadContact(const KContacts::Addressee &contact)
 {
-    mPicture = (mType == Photo ? contact.photo() : contact.logo());
+    mPicture = (mType == Photo) ? contact.photo() : contact.logo();
     if (mPicture.isIntern() && !mPicture.data().isNull()) {
         mHasImage = true;
     } else if (!mPicture.isIntern() && !mPicture.url().isEmpty()) {
@@ -237,7 +237,7 @@ void ImageWidget::mouseMoveEvent(QMouseEvent *event)
             QDrag *drag = new QDrag(this);
             drag->setMimeData(new QMimeData());
             drag->mimeData()->setImageData(mPicture.data());
-            drag->start();
+            drag->exec(Qt::CopyAction);
         }
     }
 }
